# Milestones
### On this page
  * [Add Milestones](https://help.sap.com/docs/leanix/ea/milestones#add-milestones)
  * [Edit and Delete Milestones](https://help.sap.com/docs/leanix/ea/milestones#edit-and-delete-milestones)
  * [Lifecycle and Cross-Project Referencing of Milestones](https://help.sap.com/docs/leanix/ea/milestones#lifecycle-and-cross-project-referencing-of-milestones)
  * [Visualizing Milestones in Reports](https://help.sap.com/docs/leanix/ea/milestones#visualizing-milestones-in-reports)


Learn how to add and manage milestones and realize their value by effectively visualizing them in reports.
A Milestone helps you create visual reference points to break a project down into manageable chunks and easily track major events and pending decisions. Milestones signal to everyone involved what a project's overall ‘lifecycle’ looks like and what needs to be achieved along the way. Milestones are added and managed in the Initiative Fact Sheet type.
  * Milestones are visible in the Roadmap Reports, every time the Initiative (Project) is the Fact Sheet or is present as a drill-down.
  * All reports with a timeline, i.e., Landscape, Matrix, and Portfolio, also display milestone icons when an Initiative/Project is projected on the timeline.
  * Milestones are available along the parent-child hierarchy so that child Fact Sheets can refer to milestones of parent Fact Sheets
  * The milestone date is automatically reflected in all the phases of an Initiative where it has been referenced. Modifying a milestone in the parent Fact Sheet automatically updates all references, simplifying the management and monitoring of dependencies between Initiatives.
![Milestones in Project Roadmap Report](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27467ded7a4410149c6edc1fbcb1b5a9_LowRes.png)
Milestones in Project Roadmap Report
